; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

[Command]
name = "CPU0"
command = U,U,D,D,B,F,B,F,s,s,s
time = 0

[Command]
name = "CPU1"
command = U,U,D,D,B,F,B,F,a,a,s
time = 0

[Command]
name = "CPU2"
command = U,U,D,D,B,F,B,F,b,b,s
time = 0

[Command]
name = "CPU3"
command = U,U,D,D,B,F,B,F,c,c,s
time = 0

[Command]
name = "CPU4"
command = U,U,D,D,B,F,B,F,x,x,s
time = 0

[Command]
name = "CPU5"
command = U,U,D,D,B,F,B,F,y,y,s
time = 0

[Command]
name = "CPU6"
command = U,U,D,D,B,F,B,F,z,z,s
time = 0

[Command]
name = "CPU7"
command = U,U,D,D,B,F,B,F,a,a,a,s
time = 0

[Command]
name = "CPU8"
command = U,U,D,D,B,F,B,F,a,a,a,a,s
time = 0

[Command]
name = "CPU9"
command = U,D,B,F,b,b,s
time = 0

[Command]
name = "CPU10"
command = D,B,F,B,F,b,b,s
time = 0

[Command]
name = "CPU11"
command = U,D,D,B,F,b,b,s
time = 0

[Command]
name = "CPU12"
command = U,U,D,F,B,F,b,s
time = 0

[Command]
name = "CPU13"
command = U,U,D,D,B,F,x,x,s
time = 0

[Command]
name = "CPU14"
command = U,U,D,D,B,F,x,s
time = 0

[Command]
name = "CPU15"
command = D,D,B,F,B,F,x,s
time = 0

[Command]
name = "CPU16"
command = D,D,B,F,B,F,x,x,s
time = 0

[Command]
name = "CPU17"
command = U,U,D,D,B,F,B,F,x,x,s
time = 0

[Command]
name = "CPU18"
command = U,U,D,B,F,B,F,x,s
time = 0

[Command]
name = "CPU19"
command = U,U,B,F,B,F,y,y,s
time = 0

[Command]
name = "CPU20"
command = U,U,D,B,F,B,F,y,y,s
time = 0

[Command]
name = "CPU21"
command = U,U,U,U,B,F,B,F,y,s
time = 0

[Command]
name = "CPU22"
command = U,U,U,U,B,F,B,F,y,y,s
time = 0

[Command]
name = "CPU23"
command = U,U,D,D,U,U,B,F,y,s
time = 0

[Command]
name = "CPU24"
command = U,U,D,D,B,F,U,U,y,s
time = 0

[Command]
name = "CPU25"
command = U,U,U,U,U,U,B,F,y,s
time = 0

[Command]
name = "CPU26"
command = U,U,D,D,U,U,B,F,x,s
time = 0

[Command]
name = "CPU27"
command = U,U,D,D,B,F,D,D,x,s
time = 0

[Command]
name = "CPU28"
command = U,D,B,F,B,F,x,x,x,s
time = 0

[Command]
name = "CPU29"
command = U,D,U,D,U,D,x,x,s
time = 0

[Command]
name = "CPU30"
command = U,D,U,D,U,D,a,s
time = 0

[Command]
name = "CPU31"
command = U,D,U,D,U,D,a,a,a,s
time = 0

[Command]
name = "CPU32"
command = B,F,B,F,B,F,B,F,a,a,s
time = 0

[Command]
name = "CPU33"
command = B,F,B,F,B,F,B,F,a,s
time = 0

[Command]
name = "CPU34"
command = U,U,B,F,B,F,B,F,b,s
time = 0

[Command]
name = "CPU35"
command = B,F,D,D,B,F,B,F,b,s
time = 0

[Command]
name = "CPU36"
command = B,F,D,D,B,F,B,F,b,b,s
time = 0

[Command]
name = "CPU37"
command = U,U,D,D,B,F,D,B,s,s
time = 0

[Command]
name = "CPU38"
command = U,U,D,D,B,F,D,B,s
time = 0

[Command]
name = "CPU39"
command = U,U,D,B,F,D,B,F,s
time = 0

[Command]
name = "CPU40"
command = U,U,D,B,F,D,B,F,a,s
time = 0

[Command]
name = "CPU41"
command = U,U,D,B,F,D,B,F,b,s
time = 0

[Command]
name = "CPU42"
command = U,U,D,B,F,D,B,F,x,s
time = 0

[Command]
name = "CPU43"
command = U,U,D,B,F,D,B,F,y,s
time = 0

[Command]
name = "CPU44"
command = U,U,D,B,F,D,B,F,a,a,s
time = 0

[Command]
name = "CPU45"
command = U,U,D,B,F,D,B,F,b,b,s
time = 0

[Command]
name = "CPU46"
command = U,U,D,B,F,D,B,F,x,x,s
time = 0

[Command]
name = "CPU47"
command = U,U,D,B,F,D,B,F,y,y,s
time = 0

[Command]
name = "CPU48"
command = U,D,B,F,F,B,s,s
time = 0

[Command]
name = "CPU49"
command = U,D,B,F,F,B,a,s
time = 0

[Command]
name = "CPU50"
command = U,D,B,F,F,B,b,s
time = 0

[Command]
name = "CPU51"
command = U,D,B,F,F,B,x,s
time = 0

[Command]
name = "CPU52"
command = U,D,B,F,F,B,y,s
time = 0

[Command]
name = "CPU53"
command = U,D,B,F,F,B,a,a,s
time = 0

[Command]
name = "CPU54"
command = U,D,B,F,F,B,b,b,s
time = 0

[Command]
name = "CPU55"
command = U,D,B,F,F,B,x,x,s
time = 0

[Command]
name = "CPU56"
command = U,D,B,F,F,B,y,y,s
time = 0

[Command]
name = "CPU57"
command = B,F,U,D,F,B,s
time = 0

[Command]
name = "CPU58"
command = B,F,U,D,F,B,x,s
time = 0

[Command]
name = "CPU59"
command = B,F,U,D,F,B,y,s
time = 0

[Command]
name = "CPU60"
command = B,F,U,D,F,B,a,s
time = 0

[Command]
name = "CPU61"
command = B,F,U,D,F,B,b
time = 0

[Command]
name = "CPU62"
command = B,F,D,F,B,U,D,F,B,s
time = 0

[Command]
name = "CPU63"
command = B,F,D,F,B,U,D,F,B,a
time = 0

[Command]
name = "CPU64"
command = B,F,D,F,B,U,D,F,B,b
time = 0

[Command]
name = "CPU65"
command = B,F,D,F,B,U,D,F,B,x
time = 0

[Command]
name = "CPU66"
command = B,F,D,F,B,U,D,F,B,y
time = 0

[Command]
name = "CPU67"
command = U,U,D,D,B,F,B,F,b
time = 0

[Command]
name = "CPU68"
command = U,U,D,D,B,F,B,F,y
time = 0

[Command]
name = "CPU69"
command = U,U,D,D,B,F,B,F,s
time = 0

[Command]
name = "CPU70"
command = U,U,D,D,B,F,B,F,a,s
time = 0


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.

[Command]
name = "Super"
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = "Super"
command = ~D, DF, F, D, DF, F, y
time = 30
;-| Special Motions |------------------------------------------------------
; One-Inch Fist
[Command]
name = "fist_x"
command = ~B, F, a


; One-Inch Fist
[Command]
name = "fist_x"
command = ~B, F, b
;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1


;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "B_a"
command = /$B, a

[Command]
name = "d_a"
command = /$D,a

[Command]
name = "down_b"
command = /$D,b
time = 1


;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1


[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Statedef -1]


;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.

[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
var(1) = 1


;Ulitmate Dragon Summon Lvl 3 Foward
[State -1, SynnSuper]
type = ChangeState
value = 2100
triggerall = var(21) != 1
triggerall = command = "Super"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl


[State -1, AI Triple Kung Fu Palm]
type = ChangeState
value = 2100
triggerall = var(0)
triggerall = power >= 1000
triggerall = statetype != A && power >= 1000 && NumProj = 0 && movetype != H
trigger1 = StateType = S && ctrl && random <= 30
trigger1 = P2StateType != L && P2Life > 0 && P2BodyDist x >= 120

;===========================================================================
; One-Inch Fist
[State -1, fist]
type = ChangeState
value = 1900
triggerall = command = "fist_x"
triggerall = statetype != A
trigger1 = ctrl

[State -1, fist]
type = ChangeState
value = 1900
triggerall = var(0)
triggerall = statetype = S
trigger1 = (stateno = 230) && time > 6
trigger1 = movehit
trigger1 = p2dist X = [0,65]
;---------------------------------------------------------------------------
;Run Fwd

[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = !var(0)
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl


;---------------------------------------------------------------------------
;^bN
[State -1]
type = ChangeState
value = 300
triggerall = command = "a"
triggerall = stateno = 100
trigger1 = statetype = S
trigger1 = ctrl = 1


;^bN
[State -1]
type = ChangeState
value = 300
triggerall = command = "b"
triggerall = stateno = 100
trigger1 = statetype = S
trigger1 = ctrl = 1

[State -1]
type = ChangeState
value = 300
triggerall = var(0)
;triggerall = !win
triggerall = p2stateno != [1025,1028]
triggerall = statetype != A
trigger1 = stateno = 100
trigger1 = movecontact &&   ctrl
;trigger1 = p2dist X>160
trigger2 = ctrl && p2dist X= [180,220]
trigger2 = P2stateno != [5110,5130]

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1300
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl


;---------------------------------------------------------------------------
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;[State -1, Stand Light Punch]
;type = ChangeState
;value = 220
;triggerall = command = "z"
;triggerall = command != "holddown"
;trigger1 = statetype = S
;trigger1 = ctrl

;---------------------------------------------------------------------------
;[State -1, Stand Light Punch]
;type = ChangeState
;value = 200
;triggerall = command = "c"
;triggerall = command != "holddown"
;trigger1 = statetype = S
;trigger1 = ctrl

;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
 ;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------
; Overhead Smash
[State -1, Overhead Smash]
type = ChangeState
value = 220
triggerall = command = "y" && command = "holdfwd" && command != "holddown"
trigger1 = StateType = S && ctrl
trigger2 = stateno = 200
trigger2 = time > 3
trigger3 = stateno = 230
trigger3 = time > 5
trigger4 = stateno = 400
trigger4 = time > 4
trigger5 = stateno = 430
trigger5 = time > 9
trigger6 = stateno = 210
trigger6 = time > 10
trigger7 = stateno = 240
trigger7 = time > 7
trigger8 = stateno = 410
trigger8 = time > 6
trigger9 = stateno = 440
trigger9 = time > 12
 ;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl



;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 240
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
[State -1, Stand Light Kick]
type = ChangeState
value = 241
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = statetype = S
;triggerall = power >= 200
;trigger1=life <= 300
trigger1=ctrl;
---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;Jump Light Punch

[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger3 = stateno = 1350 ;Air blocking

[State -1, AI Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(0)
trigger1 = stateno = 600
trigger1 = statetime >= 7
trigger1 = movecontact
trigger1 = p2dist X-(vel X*7)<=40
trigger1 = prevstateno != 600
trigger2 = stateno != 600
trigger2 = statetype = A
trigger2 = ctrl
trigger2 = p2bodydist X<=30
trigger2 = p2statetype = A
trigger2 = p2dist Y = [-60,10]

;---------------------------------------------------------------------------
;Jump Strong Punch

[State -1, Jump Strong Punch]
type = ChangeState
value = 600
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

[State -1, AI Jump Strong Punch]
type = ChangeState
value = 600
triggerall = var(0)
trigger1 = stateno = 600
trigger1 = statetime >= 7
trigger1 = movecontact
trigger1 = (prevstateno = 600) || (p2dist X-(vel X*7)>40)


[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = !var(0)
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking

[State -1, AI Jump Light Kick]
type = ChangeState
value = 630
triggerall = var(0)
triggerall = p2dist Y>20
triggerall = p2dist X = [0,40]
triggerall = statetype = A
trigger1 = p2statetype = S
trigger1 = vel Y>0
trigger1 = ctrl
trigger2 = vel Y>0
trigger2 = command = "a"
trigger2 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Kick

[State -1, Jump Strong Kick]
type = ChangeState
value = 630
triggerall = !var(0)
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

[State -1, AI Jump Strong Kick]
type = ChangeState
value = 630
triggerall = var(0)
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = p2statetype = C
trigger1 = vel Y>0
trigger1 = pos Y>-60
trigger1 = p2dist X<80
trigger2 = stateno = 630 ;jump_x or jump_a
trigger2 = movecontact


;---------------------------------------------------------------------------

